import numpy as np
import pandas as pd

import imviz as viz

"""

Inspired by the imgui/implot demo files this file demonstrates the usage of
imviz by example.

"""


def main():

    xs = np.arange(0.0, 100.0, 0.1)
    ys = np.random.rand(1000)

    frame = pd.DataFrame({"xs": xs, "ys": ys})

    frame_selection = []

    multi_selection = []

    test_string: str = "This is a test"
    steering_angle: float = 0.0

    asdf: bool = False

    img = np.random.rand(240, 320)
    img = img.astype("float32")

    display_width = 0.0
    display_height = 0.0

    target_pos = (0.0, 0.0)

    while viz.wait():

        if viz.figure("Test"):
            viz.plot([1, 2, 3], [1, 2, 3], shade=[0.2, 0.1, 0.3], fmt="-o")

        if viz.figure("Test2"):

            target_pos, mod = viz.drag_point("dst", target_pos, True, [1.0, 0.0, 0.0], 20)
            viz.plot(xs, ys, "-o")

        if viz.begin("Other"):

            viz.text("Test", color=(1.0, 0.0, 0.0))

            if viz.button("blub"):
                print("Test")

            test_string, mod = viz.input("InputTest", test_string)
            if mod:
                print(test_string)

            steering_angle, mod = viz.input("Input2", steering_angle)
            if mod:
                print(steering_angle)

            asdf, mod = viz.checkbox("TestBool", asdf)
            if mod:
                print(asdf)

            viz.dataframe(frame, "TestFrame", frame_selection)

            if (viz.multiselect(
                    "Select something",
                    ["values", "blub", "test"],
                    multi_selection)):

                print("Multiselection changed!")

        viz.end()

        if viz.begin("Tab Test"):
            if viz.begin_tab_bar("TabBar"):
                if viz.begin_tab_item("TestItem"):
                    viz.text("Hello")
                    viz.end_tab_item()
                if viz.begin_tab_item("TestItem2"):
                    viz.text("Hello2")
                    viz.end_tab_item()
                viz.end_tab_bar()

        viz.end()

        if viz.begin("Image test"):

            display_width, mod = viz.slider("Display Width", display_width, 0.0, 1000)
            display_height, mod = viz.slider("Display Height", display_height, 0.0, 1000)

                #viz.plot([1, 2, 3], [1, 2, 3])

                #viz.imshow("test_image",
                #           img,
                #           int(display_width),
                #           int(display_height))

        viz.end()


if __name__ == "__main__":
    main()



import os
import sys
import platform
import subprocess
import multiprocessing

from pathlib import Path

from setuptools import setup, Extension, find_packages
from setuptools.command.build_ext import build_ext


# Setuptools calls cmake, which takes care of further
# C++ dependency resolution and the extension build.

# Inspired by:
# https://gist.github.com/hovren/5b62175731433c741d07ee6f482e2936
# https://www.benjack.io/2018/02/02/python-cpp-revisited.html
# Thanks a lot, very helpful :)


class CMakeExtension(Extension):
    def __init__(self, name):
        Extension.__init__(self, name, sources=[])


class CMakeBuild(build_ext):

    def run(self):

        try:
            _ = subprocess.check_output(['cmake', '--version'])
        except OSError:
            raise RuntimeError(
                "CMake must be installed to build the following extensions: " +
                ", ".join(e.name for e in self.extensions))

        # preparing cmake arguments

        cmake_args = [
            ('-DCMAKE_LIBRARY_OUTPUT_DIRECTORY='
                + os.path.abspath(self.build_temp)),
            '-DPYTHON_EXECUTABLE=' + sys.executable
        ]

        # determining build type

        cfg = 'Debug' if self.debug else 'Release'
        self.build_args = ['--config', cfg]

        cmake_args += ['-DCMAKE_BUILD_TYPE=' + cfg]

        # parallelize compilation, if using make files

        if not platform.system() == "Windows":
            cpu_count = multiprocessing.cpu_count()
            self.build_args += ['--', '-j{}'.format(cpu_count)]

        # additional flags

        env = os.environ.copy()
        env['CXXFLAGS'] = '{} -DVERSION_INFO=\\"{}\\"'.format(
                                env.get('CXXFLAGS', ''),
                                self.distribution.get_version())

        if not os.path.exists(self.build_temp):
            os.makedirs(self.build_temp)

        # call cmake to configure and build

        cmake_dir = os.path.abspath(os.path.dirname(__file__))

        subprocess.check_call(['cmake', cmake_dir] + cmake_args,
                              cwd=self.build_temp,
                              env=env)

        cmake_cmd = ['cmake', '--build', '.'] + self.build_args

        subprocess.check_call(cmake_cmd, cwd=self.build_temp)

        # move from temp. build dir to final position

        for ext in self.extensions:

            build_temp = Path(self.build_temp).resolve()
            dest_path = Path(self.get_ext_fullpath(ext.name)).resolve()
            source_path = build_temp / self.get_ext_filename(ext.name)

            dest_directory = dest_path.parents[0]
            dest_directory.mkdir(parents=True, exist_ok=True)

            self.copy_file(source_path, dest_path)


setup(name="imviz",
      version="0.1",
      description="Pythonic bindings for imgui/implot",
      url="https://github.com/joruof/imviz",
      author="Jona Ruof",
      author_email="jona.ruof@uni-ulm.de",
      license="MIT",
      zip_safe=False,
      python_requires=">=3.6",
      packages=find_packages(),
      ext_modules=[CMakeExtension("imviz")],
      cmdclass=dict(build_ext=CMakeBuild),
      include_package_data=True,
      #package_data={"": ["*.txt"]}
      )
